@@ -63,10 +63,13 @@ x86_64_init (Elf *elf __attribute__ ((unused)),
   /* gcc/config/ #define DWARF_FRAME_REGISTERS.  */
   eh->frame_nregs = 17;
   HOOK (eh, set_initial_registers_tid);
-  HOOK (eh, set_initial_registers_sample);
-  HOOK (eh, sample_base_addr);
-  HOOK (eh, sample_pc);
+  /* set_initial_registers_sample is default ver */
+  HOOK (eh, sample_sp_pc);
+  HOOK (eh, sample_perf_regs_mapping);
   eh->perf_frame_regs_mask = PERF_FRAME_REGISTERS_X86_64;
+  eh->cached_perf_regs_mask = 0;
+  eh->cached_regs_mapping = NULL;
+  eh->cached_n_regs_mapping = -1;
   HOOK (eh, unwind);
   HOOK (eh, check_reloc_target_type);
 
