@@ -1,5 +1,5 @@
 /* Return offset of DIE in CU.
-   Copyright (C) 2003-2010 Red Hat, Inc.
+   Copyright (C) 2003-2010, 2014 Red Hat, Inc.
    This file is part of elfutils.
    Written by Ulrich Drepper <drepper@redhat.com>, 2003.
 
@@ -36,10 +36,9 @@
 
 
 Dwarf_Off
-dwarf_cuoffset (die)
-     Dwarf_Die *die;
+dwarf_cuoffset (Dwarf_Die *die)
 {
-  return (die == NULL
+  return ((die == NULL || die->cu == NULL)
 	  ? (Dwarf_Off) -1l
-	  : (die->addr - cu_data (die->cu)->d_buf - die->cu->start));
+	  : (Dwarf_Off) (die->addr - die->cu->startp));
 }
