@@ -1,5 +1,5 @@
 /* Interfaces for libdwfl.
-   Copyright (C) 2005-2010, 2013 Red Hat, Inc.
+   Copyright (C) 2005-2010, 2013, 2024 Red Hat, Inc.
    This file is part of elfutils.
 
    This file is free software; you can redistribute it and/or modify
@@ -42,13 +42,32 @@ typedef struct Dwfl_Module Dwfl_Module;
 typedef struct Dwfl_Line Dwfl_Line;
 
 /* This holds information common for all the frames of one backtrace for
-   a partical thread/task/TID.  Several threads belong to one Dwfl.  */
+   a particular thread/task/TID.  Several threads belong to one Dwfl.  */
 typedef struct Dwfl_Thread Dwfl_Thread;
 
 /* This holds everything we know about the state of the frame at a particular
    PC location described by an FDE belonging to Dwfl_Thread.  */
 typedef struct Dwfl_Frame Dwfl_Frame;
 
+/* This identifies the method used to unwind a particular Dwfl_Frame.
+   The enum order matches the order of preference for unwinding
+   (i.e. eh_frame is preferred to dwarf is preferred to ebl). */
+typedef enum {
+    DWFL_UNWOUND_NONE = 0,
+    DWFL_UNWOUND_INITIAL_FRAME,
+    DWFL_UNWOUND_EH_CFI,
+    DWFL_UNWOUND_DWARF_CFI,
+    DWFL_UNWOUND_EBL,
+    /* Keep this the last entry.  */
+    DWFL_UNWOUND_NUM,
+} Dwfl_Unwound_Source;
+
+/* Handle for debuginfod-client connection.  */
+#ifndef _ELFUTILS_DEBUGINFOD_CLIENT_TYPEDEF
+typedef struct debuginfod_client debuginfod_client;
+#define _ELFUTILS_DEBUGINFOD_CLIENT_TYPEDEF 1
+#endif
+
 /* Callbacks.  */
 typedef struct
 {
@@ -156,6 +175,10 @@ extern Dwfl_Module *dwfl_report_elf (Dwfl *dwfl, const char *name,
 extern Dwfl_Module *dwfl_report_offline (Dwfl *dwfl, const char *name,
 					 const char *file_name, int fd);
 
+/* Similar, but report ELF from memory region.  */
+extern Dwfl_Module *dwfl_report_offline_memory (Dwfl *dwfl, const char *name,
+						const char *file_name,
+						char *data, size_t size);
 
 /* Finish reporting the current set of modules to the library.
    If REMOVED is not null, it's called for each module that
@@ -471,28 +494,28 @@ extern const char *dwfl_module_addrname (Dwfl_Module *mod, GElf_Addr address);
 
 /* Find the symbol associated with ADDRESS.  Return its name or NULL
    when nothing was found.  If the architecture uses function
-   descriptors, and symbol st_value points to one, ADDRESS wil be
+   descriptors, and symbol st_value points to one, ADDRESS will be
    matched against either the adjusted st_value or the associated
-   function entry value as described in dwfl_module_getsym_info.  If
-   OFFSET is not NULL it will be filled in with the difference from
-   the start of the symbol (or function entry).  If SYM is not NULL it
-   is filled in with the symbol associated with the matched ADDRESS.
-   The SYM->ST_VALUE itself isn't adjusted in any way.  Fills in ELFP,
-   if not NULL, with the ELF file the symbol originally came from.
-   Note that symbols can come from either the main, debug or auxiliary
-   ELF symbol file (either dynsym or symtab).  If SHNDXP is non-null,
-   it's set with the section index (whether from st_shndx or extended
-   index table).  Fills in BIAS, if not NULL, with the difference
-   between addresses within the loaded module and those in symbol
-   table of the ELF file.  Note that the address matched against the
-   symbol might be in a different section than the returned symbol.
-   The section in the main elf file in ADDRESS falls can be found with
-   dwfl_module_address_section.  */
+   function entry value as described in dwfl_module_getsym_info.
+   OFFSET will be filled in with the difference from the start of the
+   symbol (or function entry), OFFSET cannot be NULL.  SYM is filled
+   in with the symbol associated with the matched ADDRESS, SYM cannot
+   be NULL.  The SYM->ST_VALUE itself isn't adjusted in any way.
+   Fills in ELFP, if not NULL, with the ELF file the symbol originally
+   came from.  Note that symbols can come from either the main, debug
+   or auxiliary ELF symbol file (either dynsym or symtab).  If SHNDXP
+   is non-null, it's set with the section index (whether from st_shndx
+   or extended index table).  Fills in BIAS, if not NULL, with the
+   difference between addresses within the loaded module and those in
+   symbol table of the ELF file.  Note that the address matched
+   against the symbol might be in a different section than the
+   returned symbol.  The section in the main elf file in ADDRESS falls
+   can be found with dwfl_module_address_section.  */
 extern const char *dwfl_module_addrinfo (Dwfl_Module *mod, GElf_Addr address,
 					 GElf_Off *offset, GElf_Sym *sym,
 					 GElf_Word *shndxp, Elf **elfp,
 					 Dwarf_Addr *bias)
-  __nonnull_attribute__ (3);
+  __nonnull_attribute__ (3, 4);
 
 /* Find the symbol that ADDRESS lies inside, and return detailed
    information as for dwfl_module_getsym (above).  Note that like
@@ -556,7 +579,7 @@ extern Dwarf_Die *dwfl_module_nextcu (Dwfl_Module *mod,
 extern Dwfl_Module *dwfl_cumodule (Dwarf_Die *cudie);
 
 
-/* Cache the source line information fo the CU and return the
+/* Cache the source line information for the CU and return the
    number of Dwfl_Line entries it has.  */
 extern int dwfl_getsrclines (Dwarf_Die *cudie, size_t *nlines);
 
@@ -738,6 +761,13 @@ pid_t dwfl_thread_tid (Dwfl_Thread *thread)
 Dwfl_Thread *dwfl_frame_thread (Dwfl_Frame *state)
   __nonnull_attribute__ (1);
 
+/* Return unwind method for frame STATE.  This function never fails.  */
+Dwfl_Unwound_Source dwfl_frame_unwound_source (Dwfl_Frame *state)
+  __nonnull_attribute__ (1);
+
+/* Return a string suitable for printing based on UNWOUND_SOURCE.  */
+const char *dwfl_unwound_source_str (Dwfl_Unwound_Source unwound_source);
+
 /* Called by Dwfl_Thread_Callbacks.set_initial_registers implementation.
    For every known continuous block of registers <FIRSTREG..FIRSTREG+NREGS)
    (inclusive..exclusive) set their content to REGS (array of NREGS items).
@@ -789,12 +819,31 @@ int dwfl_getthread_frames (Dwfl *dwfl, pid_t tid,
 
 /* Return *PC (program counter) for thread-specific frame STATE.
    Set *ISACTIVATION according to DWARF frame "activation" definition.
-   Typically you need to substract 1 from *PC if *ACTIVATION is false to safely
+   Typically you need to subtract 1 from *PC if *ACTIVATION is false to safely
    find function of the caller.  ACTIVATION may be NULL.  PC must not be NULL.
    Function returns false if it failed to find *PC.  */
 bool dwfl_frame_pc (Dwfl_Frame *state, Dwarf_Addr *pc, bool *isactivation)
   __nonnull_attribute__ (1, 2);
 
+/* Get the value of the DWARF register number in the given frame.
+   Returns zero on success, -1 on error (invalid DWARF register
+   number) or 1 if the value of the register in the frame is unknown.  */
+int dwfl_frame_reg (Dwfl_Frame *state, unsigned regno, Dwarf_Word *val)
+  __nonnull_attribute__ (1);
+
+/* Return the internal debuginfod-client connection handle for the DWFL session.
+   When the client connection has not yet been initialized, it will be done on the
+   first call to this function. If elfutils is compiled without support for debuginfod,
+   NULL will be returned.
+ */
+extern debuginfod_client *dwfl_get_debuginfod_client (Dwfl *dwfl);
+
+/* Set the sysroot to use when searching for shared libraries and binaries. If not
+   specified, search the system root. Passing NULL clears previously set sysroot. Note
+   that library creates a copy of the sysroot argument.  */
+int dwfl_set_sysroot (Dwfl *dwfl, const char *sysroot)
+  __nonnull_attribute__ (1);
+
 #ifdef __cplusplus
 }
 #endif
