@@ -47,13 +47,25 @@ elf_cvt_note (void *dest, const void *src, size_t len, int encode,
       note_len += n->n_namesz;
       note_len = nhdr8 ? NOTE_ALIGN8 (note_len) : NOTE_ALIGN4 (note_len);
       if (note_len > len || note_len < sizeof *n)
-	break;
+	{
+	  /* Header was translated, nothing else.  */
+	  len -= sizeof *n;
+	  src += sizeof *n;
+	  dest += sizeof *n;
+	  break;
+	}
 
       /* data as a whole needs to be aligned.  */
       note_len += n->n_descsz;
       note_len = nhdr8 ? NOTE_ALIGN8 (note_len) : NOTE_ALIGN4 (note_len);
       if (note_len > len || note_len < sizeof *n)
-	break;
+	{
+	  /* Header was translated, nothing else.  */
+	  len -= sizeof *n;
+	  src += sizeof *n;
+	  dest += sizeof *n;
+	  break;
+	}
 
       /* Copy or skip the note data.  */
       size_t note_data_len = note_len - sizeof *n;
