@@ -33,6 +33,11 @@ testrun ${abs_top_builddir}/src/elflint -q testfile33
 testfiles testfile42
 testrun ${abs_top_builddir}/src/elflint -q --gnu-ld testfile42
 
+# Contains debuginfo, compress it, recheck
+tempfiles testfile42z
+testrun ${abs_top_builddir}/src/elfcompress -f -q -o testfile42z testfile42
+testrun ${abs_top_builddir}/src/elflint -q --gnu-ld testfile42z
+
 testfiles testfile46
 testrun ${abs_top_builddir}/src/elflint -q testfile46
 
@@ -47,4 +52,9 @@ testrun ${abs_top_builddir}/src/elflint -q --gnu-ld testlib_dynseg.so
 testfiles testfile-s390x-hash-both
 testrun ${abs_top_builddir}/src/elflint -q --gnu-ld testfile-s390x-hash-both
 
+# Compress the symtab/strtab just because and recheck
+tempfiles testfile-s390x-hash-bothz
+testrun ${abs_top_builddir}/src/elfcompress -f -q --name='.s??tab' -o testfile-s390x-hash-bothz testfile-s390x-hash-both
+testrun ${abs_top_builddir}/src/elflint -q --gnu-ld testfile-s390x-hash-bothz
+
 exit 0
