@@ -17,5 +17,10 @@
 
 . $srcdir/test-subr.sh
 
+if test -n "$ELFUTILS_MEMORY_SANITIZER"; then
+  echo "binaries linked with memory sanitizer are too big"
+  exit 77
+fi
+
 # Just makes sure readelf doesn't crash
-testrun_on_self_quiet ${abs_top_builddir}/src/readelf -a -w
+testrun_on_self_quiet ${abs_top_builddir}/src/readelf -N -a -w
